# coding=utf-8
from collections import OrderedDict
from datetime import timedelta


# The time offset for the whole session. This is necessary if the videos would scroll in the negative time.
# It says how much later the video should be started to prevent this negativ time.
session_time_offset = 0.0
# The offset of the videos to show it in giant.
video_offsets = 0.0

# The timestamps of the start time of each video for this session.
video_timestamps = {
    "kinect": 1510150597,
    "camUser": 1510150597.5,
    # "camWall": 0.0,
}

# Timestamps of each phase in this session
phase_timestamps = OrderedDict([
    ("Training Touch", ("15:17:16:436412", "15:32:06.684332")),
    ("Training Pointing", ("15:34:28.790879", "15:45:36.681007")),
    ("Guided Exploration", ("15:47:51.167539", "16:08:51.789508")),
    ("Free Exploration", ("16:09:58:550991", "16:22:47.753389"))
])

# The joint that will be used to calculate the distance between the body and the device or touch.
joint_type_body_to_device = "OKS_SPINE_MID"
joint_type_body_to_touch = "OKS_SPINE_SHOULDER"

# Values for the mapping of device ids to the skeleton ids:

# How many times should a device id be counted to assume that it can be coupled with a given skeleton id.
device_id_count_threshold = 5
# The time difference between the body and the device movement.
max_time_delta_body_to_device = timedelta(milliseconds=150)
# The maximal distance between a device and any body to be accounted for.
max_dist_delta_body_to_device = 0.55  # in m

# values for the mapping of touches to users (body and devices):

# The time difference between an touch on the wall and an injection.
max_time_delta_touch_to_inj = timedelta(milliseconds=150)
# The time delta between an injection of a touch to the wall and an interaction on the device itself.
max_time_delta_inj_to_de = timedelta(milliseconds=3)
# The time differencte between the body movement and the occurence of a touch on the wall.
max_time_delta_body_to_touch = timedelta(milliseconds=75)
# The minimal distance that is requiered between an touch and a body (only the z-position value).
min_body_dist_to_wall = 0.85  # in m
# The average arm span of the user in this study.
arm_span = 1.0  # in m

# Should touches with a -1 id be ignored. They will not be written to the giant_* output file.
ignore_not_found_touch_ids = False
# All skeleton ids that will be entered here will be removed from the giant_* output files.
ignore_skeleton_ids = [
    '72057594037927962',
    '72057594037928004',
    '72057594037930917',
    '72057594037930930',
    '72057594037930939'
]
# If the divico_to_giant is run once, it will create a file with the name session_*_skeleton_id_mapping.txt. The content
# of this file can be added here and can be modified.
user_ids = {
    '72057594037927961': 2,
    '72057594037927962': 3,
    '72057594037928004': 4,
    '72057594037928007': 1,
    '72057594037928116': 2,
    '72057594037928125': 1,
    '72057594037928209': 2,
    '72057594037928227': 1,
    '72057594037928308': 2,
    '72057594037929019': 1,
    '72057594037929052': 2,
    '72057594037929108': 1,
    '72057594037929110': 1,
    '72057594037929516': 1,
    '72057594037929541': 2,
    '72057594037929573': 1,
    '72057594037929663': 2,
    '72057594037929783': 2,
    '72057594037930341': 2,
    '72057594037930466': 1,
    '72057594037930494': 2,
    '72057594037930694': 2,
    '72057594037930838': 1,
    '72057594037930869': 2,
    '72057594037930917': 5,
    '72057594037930930': 6,
    '72057594037930939': 7,
    '72057594037930954': 2,
    '72057594037931000': 1,
    '72057594037931313': 1,
    '72057594037931353': 1,
    '72057594037933036': 1
}
