# coding=utf-8
from collections import OrderedDict
from datetime import timedelta


# The time offset for the whole session. This is necessary if the videos would scroll in the negative time.
# It says how much later the video should be started to prevent this negativ time.
session_time_offset = 0.0
# The offset of the videos to show it in giant.
video_offsets = 0.0

# The timestamps of the start time of each video for this session.
video_timestamps = {
    "kinect": 1510921303,
    "camUser": 1510921307,
    "camWall": 1510921300.1,
}

# Timestamps of each phase in this session
phase_timestamps = OrderedDict([
    ("Training Touch", ("13:22:08.633193", "13:42:53.312948")),
    ("Training Pointing", ("13:46:53.335395", "13:55:42.653948")),
    ("Guided Exploration", ("13:58:56.015732", "14:36:06.395389")),
    ("Free Exploration", ("14:36:28.419222", "14:46:13.473777"))
])

# The joint that will be used to calculate the distance between the body and the device or touch.
joint_type_body_to_device = "OKS_SPINE_MID"
joint_type_body_to_touch = "OKS_SPINE_SHOULDER"

# Values for the mapping of device ids to the skeleton ids:

# How many times should a device id be counted to assume that it can be coupled with a given skeleton id.
device_id_count_threshold = 5
# The time difference between the body and the device movement.
max_time_delta_body_to_device = timedelta(milliseconds=150)
# The maximal distance between a device and any body to be accounted for.
max_dist_delta_body_to_device = 0.55  # in m

# values for the mapping of touches to users (body and devices):

# The time difference between an touch on the wall and an injection.
max_time_delta_touch_to_inj = timedelta(milliseconds=150)
# The time delta between an injection of a touch to the wall and an interaction on the device itself.
max_time_delta_inj_to_de = timedelta(milliseconds=3)
# The time differencte between the body movement and the occurence of a touch on the wall.
max_time_delta_body_to_touch = timedelta(milliseconds=75)
# The minimal distance that is requiered between an touch and a body (only the z-position value).
min_body_dist_to_wall = 0.85  # in m
# The average arm span of the user in this study.
arm_span = 1.0  # in m

# Should touches with a -1 id be ignored. They will not be written to the giant_* output file.
ignore_not_found_touch_ids = False
# All skeleton ids that will be entered here will be removed from the giant_* output files.
ignore_skeleton_ids = [
    '72057594037936973',
    '72057594037937084',
    '72057594037937923',
    '72057594037939925',
    '72057594037941140'
]
# If the divico_to_giant is run once, it will create a file with the name session_*_skeleton_id_mapping.txt. The content
# of this file can be added here and can be modified.
user_ids = {
    '72057594037936973': 3,
    '72057594037937084': 4,
    '72057594037937085': 1,
    '72057594037937467': 2,
    '72057594037937614': 1,
    '72057594037937923': 7,
    '72057594037938433': 2,
    '72057594037938434': 1,
    '72057594037938458': 2,
    '72057594037938536': 2,
    '72057594037938540': 1,
    '72057594037938626': 1,
    '72057594037939846': 1,
    '72057594037939892': 2,
    '72057594037939925': 8,
    '72057594037939935': 2,
    '72057594037939947': 2,
    '72057594037939970': 2,
    '72057594037940064': 2,
    '72057594037940285': 1,
    '72057594037940360': 2,
    '72057594037940518': 1,
    '72057594037940736': 2,
    '72057594037940775': 2,
    '72057594037940804': 2,
    '72057594037940835': 2,
    '72057594037940954': 2,
    '72057594037940973': 2,
    '72057594037941067': 1,
    '72057594037941140': 9
}
