# coding=utf-8
from collections import OrderedDict
from datetime import timedelta


# The time offset for the whole session. This is necessary if the videos would scroll in the negative time.
# It says how much later the video should be started to prevent this negativ time.
session_time_offset = 0.0
# The offset of the videos to show it in giant.
video_offsets = 0.0

# The timestamps of the start time of each video for this session.
video_timestamps = {
    "kinect": 1510821700,
    "camUser": 1510821704.9,
    "camWall": 1510821697.9,
}


# Timestamps of each phase in this session
phase_timestamps = OrderedDict([
    ("Training Pointing", ("09:42:34.381218", "10:00:05.794783")),
    ("Training Touch", ("10:03:06.533545", "10:10:56.188533")),
    ("Guided Exploration", ("10:13:26.892765", "10:34:18.508690")),
    ("Free Exploration", ("10:38:44.000500", "10:42:17.283676"))
])

# The joint that will be used to calculate the distance between the body and the device or touch.
joint_type_body_to_device = "OKS_SPINE_MID"
joint_type_body_to_touch = "OKS_SPINE_SHOULDER"

# Values for the mapping of device ids to the skeleton ids:

# How many times should a device id be counted to assume that it can be coupled with a given skeleton id.
device_id_count_threshold = 5
# The time difference between the body and the device movement.
max_time_delta_body_to_device = timedelta(milliseconds=150)
# The maximal distance between a device and any body to be accounted for.
max_dist_delta_body_to_device = 0.55  # in m

# values for the mapping of touches to users (body and devices):

# The time difference between an touch on the wall and an injection.
max_time_delta_touch_to_inj = timedelta(milliseconds=150)
# The time delta between an injection of a touch to the wall and an interaction on the device itself.
max_time_delta_inj_to_de = timedelta(milliseconds=3)
# The time differencte between the body movement and the occurence of a touch on the wall.
max_time_delta_body_to_touch = timedelta(milliseconds=75)
# The minimal distance that is requiered between an touch and a body (only the z-position value).
min_body_dist_to_wall = 0.85  # in m
# The average arm span of the user in this study.
arm_span = 1.0  # in m

# Should touches with a -1 id be ignored. They will not be written to the giant_* output file.
ignore_not_found_touch_ids = False
# All skeleton ids that will be entered here will be removed from the giant_* output files.
ignore_skeleton_ids = [
    '72057594037927961',
    '72057594037928002',
    '72057594037928024',
    '72057594037928089',
    '72057594037928135',
    '72057594037928136',
    '72057594037928776',
    '72057594037929926'
]
# If the divico_to_giant is run once, it will create a file with the name session_*_skeleton_id_mapping.txt. The content
# of this file can be added here and can be modified.
user_ids = {
    '72057594037927961': 3,
    '72057594037928002': 4,
    '72057594037928024': 5,
    '72057594037928089': 9,
    '72057594037928135': 7,
    '72057594037928136': 8,
    '72057594037928295': 1,
    '72057594037928333': 2,
    '72057594037928334': 2,
    '72057594037928381': 2,
    '72057594037928405': 1,
    '72057594037928408': 1,
    '72057594037928541': 2,
    '72057594037928720': 2,
    '72057594037928730': 2,
    '72057594037928776': 12,
    '72057594037928809': 2,
    '72057594037928896': 1,
    '72057594037928942': 2,
    '72057594037928957': 2,
    '72057594037928979': 1,
    '72057594037928985': 2,
    '72057594037929009': 1,
    '72057594037929082': 1,
    '72057594037929160': 1,
    '72057594037929258': 2,
    '72057594037929304': 2,
    '72057594037929313': 2,
    '72057594037929368': 1,
    '72057594037929381': 2,
    '72057594037929423': 2,
    '72057594037929446': 2,
    '72057594037929479': 1,
    '72057594037929493': 2,
    '72057594037929538': 2,
    '72057594037929882': 1,
    '72057594037929926': 13
}
