# coding=utf-8
from collections import OrderedDict
from datetime import timedelta


# The time offset for the whole session. This is necessary if the videos would scroll in the negative time.
# It says how much later the video should be started to prevent this negativ time.
session_time_offset = 1.0
# The offset of the videos to show it in giant.
video_offsets = 0.0

# The timestamps of the start time of each video for this session.
video_timestamps = {
    "kinect": 1512032975,
    "camUser": 1512032985.8,
    "camWall": 1512032982,
}

# Timestamps of each phase in this session
phase_timestamps = OrderedDict([
    ("Training Pointing", ("10:10:15.763560", "10:26:53.216723")),
    ("Training Touch", ("10:29:41.473842", "10:38:34.075534")),
    ("Guided Exploration", ("10:42:41.516145", "11:12:54.854565")),
    ("Free Exploration", ("11:13:11.907904", "11:25:39.371318"))
])

# The joint that will be used to calculate the distance between the body and the device or touch.
joint_type_body_to_device = "OKS_SPINE_MID"
joint_type_body_to_touch = "OKS_SPINE_SHOULDER"

# Values for the mapping of device ids to the skeleton ids:

# How many times should a device id be counted to assume that it can be coupled with a given skeleton id.
device_id_count_threshold = 5
# The time difference between the body and the device movement.
max_time_delta_body_to_device = timedelta(milliseconds=150)
# The maximal distance between a device and any body to be accounted for.
max_dist_delta_body_to_device = 0.55  # in m

# values for the mapping of touches to users (body and devices):

# The time difference between an touch on the wall and an injection.
max_time_delta_touch_to_inj = timedelta(milliseconds=150)
# The time delta between an injection of a touch to the wall and an interaction on the device itself.
max_time_delta_inj_to_de = timedelta(milliseconds=3)
# The time differencte between the body movement and the occurence of a touch on the wall.
max_time_delta_body_to_touch = timedelta(milliseconds=75)
# The minimal distance that is requiered between an touch and a body (only the z-position value).
min_body_dist_to_wall = 0.85  # in m
# The average arm span of the user in this study.
arm_span = 1.0  # in m

# Should touches with a -1 id be ignored. They will not be written to the giant_* output file.
ignore_not_found_touch_ids = False
# All skeleton ids that will be entered here will be removed from the giant_* output files.
ignore_skeleton_ids = [
    '72057594037928039',
    '72057594037928093',
    '72057594037928430'
]
# If the divico_to_giant is run once, it will create a file with the name session_*_skeleton_id_mapping.txt. The content
# of this file can be added here and can be modified.
user_ids = {
    '72057594037928039': 3,
    '72057594037928093': 4,
    '72057594037928152': 1,
    '72057594037928430': 5,
    '72057594037928678': 2,
    '72057594037928687': 2,
    '72057594037928709': 2,
    '72057594037928791': 2,
    '72057594037928829': 2,
    '72057594037929190': 1,
    '72057594037929282': 2,
    '72057594037929339': 2,
    '72057594037929435': 2,
    '72057594037929475': 2,
    '72057594037929506': 2,
    '72057594037929638': 1,
    '72057594037929719': 2,
    '72057594037929920': 2,
    '72057594037930019': 1,
    '72057594037930095': 1,
    '72057594037930123': 1,
    '72057594037930569': 1,
    '72057594037930818': 1,
    '72057594037930819': 2,
    '72057594037930820': 2,
    '72057594037931041': 2,
    '72057594037931117': 2,
    '72057594037931146': 2,
    '72057594037931215': 1,
    '72057594037931221': 1,
    '72057594037931248': 2,
    '72057594037931352': 1,
    '72057594037931452': 2,
    '72057594037931523': 1,
    '72057594037931758': 2,
    '72057594037931780': 2,
    '72057594037931965': 2,
    '72057594037932171': 2,
    '72057594037932206': 2,
    '72057594037932473': 1,
    '72057594037932473-1': 2,
    '72057594037932839': 1
}

# TODO: Von 10:46 - 10:47 nur eine kinect id
